# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.course_content_block import CourseContentBlock

class TestCourseContentBlock(unittest.TestCase):
    """CourseContentBlock unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CourseContentBlock:
        """Test CourseContentBlock
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CourseContentBlock`
        """
        model = CourseContentBlock()
        if include_optional:
            return CourseContentBlock(
                block_type = 'text',
                order = 56,
                is_expanded = True,
                content = public_api_server_connector_v2.models.content.Content(
                    link = '', 
                    file_id = '', 
                    audio_id = '', 
                    payload = '', 
                    btn_url = '', 
                    btn_font = '', 
                    btn_size = null, 
                    btn_text = '', 
                    btn_color = '', 
                    btn_target = null, 
                    btn_position = null, 
                    btn_text_color = '', 
                    pdf_id = '', ),
                id = 56,
                course_id = 56,
                created_at = 56
            )
        else:
            return CourseContentBlock(
                block_type = 'text',
                order = 56,
                is_expanded = True,
                id = 56,
                course_id = 56,
                created_at = 56,
        )
        """

    def testCourseContentBlock(self):
        """Test CourseContentBlock"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.course_create import CourseCreate

class TestCourseCreate(unittest.TestCase):
    """CourseCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CourseCreate:
        """Test CourseCreate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CourseCreate`
        """
        model = CourseCreate()
        if include_optional:
            return CourseCreate(
                title = '',
                image_id = '',
                description = '',
                url = '',
                payload = '',
                module_view_type = 'list',
                payment_type = 'paid',
                course_access_type = 'subscription',
                number_days_access = 56,
                is_active = True,
                is_secret = True,
                is_archived = True,
                is_displayed_in_app = True,
                is_offline_downloadable = True,
                available_at = 56,
                launch_date_enabled = True,
                launch_date = 56,
                order = 56
            )
        else:
            return CourseCreate(
                title = '',
                is_active = True,
                is_secret = True,
                is_archived = True,
                is_displayed_in_app = True,
                is_offline_downloadable = True,
        )
        """

    def testCourseCreate(self):
        """Test CourseCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from public_api_server_connector_v2.models.category_method_options import CategoryMethodOptions
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class Category(BaseModel):
    """
    Category
    """ # noqa: E501
    name: StrictStr
    create: Optional[CategoryMethodOptions] = None
    read: Optional[CategoryMethodOptions] = None
    update: Optional[CategoryMethodOptions] = None
    delete: Optional[CategoryMethodOptions] = None
    __properties: ClassVar[List[str]] = ["name", "create", "read", "update", "delete"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Category from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of create
        if self.create:
            _dict['create'] = self.create.to_dict()
        # override the default output from pydantic by calling `to_dict()` of read
        if self.read:
            _dict['read'] = self.read.to_dict()
        # override the default output from pydantic by calling `to_dict()` of update
        if self.update:
            _dict['update'] = self.update.to_dict()
        # override the default output from pydantic by calling `to_dict()` of delete
        if self.delete:
            _dict['delete'] = self.delete.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Category from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "create": CategoryMethodOptions.from_dict(obj["create"]) if obj.get("create") is not None else None,
            "read": CategoryMethodOptions.from_dict(obj["read"]) if obj.get("read") is not None else None,
            "update": CategoryMethodOptions.from_dict(obj["update"]) if obj.get("update") is not None else None,
            "delete": CategoryMethodOptions.from_dict(obj["delete"]) if obj.get("delete") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.response_wrapper_course import ResponseWrapperCourse

class TestResponseWrapperCourse(unittest.TestCase):
    """ResponseWrapperCourse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperCourse:
        """Test ResponseWrapperCourse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperCourse`
        """
        model = ResponseWrapperCourse()
        if include_optional:
            return ResponseWrapperCourse(
                done = True,
                result = public_api_server_connector_v2.models.course.Course(
                    title = '', 
                    image_id = '', 
                    description = '', 
                    url = '', 
                    payload = '', 
                    module_view_type = null, 
                    payment_type = null, 
                    course_access_type = null, 
                    number_days_access = 56, 
                    is_active = True, 
                    is_secret = True, 
                    is_archived = True, 
                    is_displayed_in_app = True, 
                    is_offline_downloadable = True, 
                    available_at = 56, 
                    launch_date_enabled = True, 
                    launch_date = 56, 
                    id = 56, 
                    portal_id = 56, 
                    order = 56, 
                    category = '', 
                    category_id = 56, 
                    sales_page_landing_id = 56, 
                    permalink = '', 
                    enable_double_optin = True, 
                    one_more_landing_id = 56, 
                    one_more_step_link = '', 
                    one_more_step_landing_id = 56, 
                    created_at_epoch = 56, 
                    modules = [
                        public_api_server_connector_v2.models.course_module.CourseModule(
                            mandatory = True, 
                            is_published = True, 
                            is_active = True, 
                            title = '', 
                            public_description = '', 
                            short_description = '', 
                            image_id = '', 
                            available_at = 56, 
                            id = 56, 
                            course_id = 56, 
                            order = 56, 
                            submodules = [
                                public_api_server_connector_v2.models.course_submodule.CourseSubmodule(
                                    order = 56, 
                                    title = '', 
                                    is_published = True, 
                                    id = 56, 
                                    module_id = 56, 
                                    created_at = 56, )
                                ], 
                            lessons = [
                                public_api_server_connector_v2.models.module_lesson.ModuleLesson(
                                    submodule_id = 56, 
                                    thread_id = 56, 
                                    lesson_type = null, 
                                    image_id = '', 
                                    title = '', 
                                    payload = '', 
                                    is_active = True, 
                                    is_published = True, 
                                    mandatory = True, 
                                    id = 56, 
                                    module_id = 56, 
                                    order = 56, 
                                    public_key = '', 
                                    content_blocks = [
                                        public_api_server_connector_v2.models.content_block.ContentBlock(
                                            block_type = null, 
                                            order = 56, 
                                            is_expanded = True, 
                                            content = null, 
                                            id = 56, 
                                            lesson_id = 56, 
                                            created_at = 56, )
                                        ], 
                                    attached_files = [
                                        public_api_server_connector_v2.models.attached_file.AttachedFile(
                                            order = 56, 
                                            file_id = 56, 
                                            id = 56, 
                                            lesson_id = 56, 
                                            created_at = 56, )
                                        ], )
                                ], )
                        ], 
                    content_blocks = [
                        public_api_server_connector_v2.models.course_content_block.CourseContentBlock(
                            block_type = 'text', 
                            order = 56, 
                            is_expanded = True, 
                            content = public_api_server_connector_v2.models.content.Content(
                                link = '', 
                                file_id = '', 
                                audio_id = '', 
                                payload = '', 
                                btn_url = '', 
                                btn_font = '', 
                                btn_size = null, 
                                btn_text = '', 
                                btn_color = '', 
                                btn_target = null, 
                                btn_position = null, 
                                btn_text_color = '', 
                                pdf_id = '', ), 
                            id = 56, 
                            course_id = 56, 
                            created_at = 56, )
                        ], ),
                error = ''
            )
        else:
            return ResponseWrapperCourse(
                done = True,
        )
        """

    def testResponseWrapperCourse(self):
        """Test ResponseWrapperCourse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
